@@ -20,7 +20,8 @@ nullmodel <- function(web, N=1000, method="r2d", ...){
     if (is.na(m)) stop("Abbreviated name does not uniquely identify method.")
     
     if (m == 1){ #r2dtable nullmodel
-        if (all(web < 2))#{
+        #if (all(web < 2)){
+        if (length(unique(web)) < 3)
             warning("This seems to be a binary web. Only methods shuffle.web and mgen should be used!\n  I proceeded nonetheless. Read the note in the help file!")
 #            m <- 5
 #        } else {
@@ -31,7 +32,8 @@ nullmodel <- function(web, N=1000, method="r2d", ...){
     }
     
     if (m == 2){# swap.web
-        if (all(web < 2))#{
+        #if (all(web < 2)){
+        if (length(unique(web)) < 3)
             warning("This seems to be a binary web. Only methods shuffle.web and mgen should be used!\n  I proceeded nonetheless. Read the note in the help file!")
 #            m <- 5
 #        } else { 
@@ -40,7 +42,8 @@ nullmodel <- function(web, N=1000, method="r2d", ...){
     }
     
     if (m == 3){ #vaznull
-        if (all(web < 2)) {
+        #if (all(web < 2)){
+        if (length(unique(web)) < 3){
         	warning("This seems to be a binary web. Only methods shuffle.web and mgen should be used!\n  I proceeded nonetheless. Read the note in the help file!")
         }
 		out <- vaznull(N, web)
